@@ -38,7 +38,7 @@ class Request:
         or  a subclass. If given,
         it is  used for HTTP requests, and any   *session_opts* passed  will raise TypeError. 
         A typical  use case is the injection of alternative caching libraries such as Cache Control.
-    **session_opts
+    session_opts :
         Additional keyword arguments are passed to
         :class:`.Session`.
     """
@@ -316,8 +316,11 @@ class Request:
             Type of resource to retrieve.
         resource_id : str, optional
             ID of the resource to retrieve.
-        tofile : str or :class:`~os.PathLike` or `file-like object`, optional
+        tofile : str or :class:`~os.PathLike` or `file-like object`, 
+            or :class:`fsspec.core.OpenFile` with 1 item, optional
             File path or file-like to write SDMX data as it is recieved.
+            *file-like* must be binary and writable. It may be used in a with-context (recommended
+when using a fsspec.core.OpenFile.
         use_cache : bool, optional
             If :obj:`True`, return a previously retrieved :class:`~.Message`
             from :attr:`cache`, or update the cache with a newly-retrieved
